@@ -23,7 +23,7 @@
 #include "../freebusyitemmodel.h"
 #include "../freebusyitem.h"
 
-#include <KCalCore/Attendee>
+#include <KCalendarCore/Attendee>
 
 #include <QTest>
 
@@ -42,11 +42,11 @@ void FreeBusyItemModelTest::testModelValidity()
 
     const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
-    KCalCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
-    KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
+    KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
 
-    fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb1->addPeriod(dt2, KCalCore::Duration(60 * 60));
+    fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb1->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
 
     FreeBusyItem::Ptr item1(new FreeBusyItem(a1, nullptr));
     item1->setFreeBusy(fb1);
@@ -58,9 +58,9 @@ void FreeBusyItemModelTest::testModelValidity()
     QModelIndex i = model->index(0, 0);
     QCOMPARE(a1.fullName(), model->data(i, Qt::DisplayRole).toString());
     QCOMPARE(a1,
-             model->data(i, FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>());
+             model->data(i, FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>());
     QCOMPARE(item1->freeBusy(),
-             model->data(i, FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>());
+             model->data(i, FreeBusyItemModel::FreeBusyRole).value<KCalendarCore::FreeBusy::Ptr>());
 
     QCOMPARE(model->rowCount(i), 2);
 
@@ -96,23 +96,23 @@ void FreeBusyItemModelTest::testModelValidity2()
     const QDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), Qt::UTC);
     const QDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), Qt::UTC);
 
-    KCalCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
-    KCalCore::Attendee a2(QStringLiteral("joe"), QStringLiteral( "joe@example.com"));
-    KCalCore::Attendee a3(QStringLiteral("max"), QStringLiteral( "max@example.com"));
-    KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
-    KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
-    KCalCore::FreeBusy::Ptr fb3(new KCalCore::FreeBusy());
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
+    KCalendarCore::Attendee a2(QStringLiteral("joe"), QStringLiteral( "joe@example.com"));
+    KCalendarCore::Attendee a3(QStringLiteral("max"), QStringLiteral( "max@example.com"));
+    KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
+    KCalendarCore::FreeBusy::Ptr fb2(new KCalendarCore::FreeBusy());
+    KCalendarCore::FreeBusy::Ptr fb3(new KCalendarCore::FreeBusy());
 
-    fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb1->addPeriod(dt2, KCalCore::Duration(60 * 60));
+    fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb1->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
 
-    fb2->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb2->addPeriod(dt2, KCalCore::Duration(60 * 60));
-    fb2->addPeriod(dt3, KCalCore::Duration(60 * 60));
+    fb2->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb2->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
+    fb2->addPeriod(dt3, KCalendarCore::Duration(60 * 60));
 
-    fb3->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb3->addPeriod(dt2, KCalCore::Duration(60 * 60));
-    fb3->addPeriod(dt4, KCalCore::Duration(60 * 60 * 2));
+    fb3->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb3->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
+    fb3->addPeriod(dt4, KCalendarCore::Duration(60 * 60 * 2));
 
     FreeBusyItem::Ptr item1(new FreeBusyItem(a1, nullptr));
     item1->setFreeBusy(fb1);
@@ -132,14 +132,14 @@ void FreeBusyItemModelTest::testModelValidity2()
     QModelIndex i1 = model->index(0, 0);
     QCOMPARE(a1.fullName(), model->data(i1, Qt::DisplayRole).toString());
     QCOMPARE(a1,
-             model->data(i1, FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>());
+             model->data(i1, FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>());
     QCOMPARE(item1->freeBusy(),
-             model->data(i1, FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>());
+             model->data(i1, FreeBusyItemModel::FreeBusyRole).value<KCalendarCore::FreeBusy::Ptr>());
 
     QModelIndex i2 = model->index(1, 0);
     QCOMPARE(a2.fullName(), model->data(i2, Qt::DisplayRole).toString());
     QCOMPARE(a2,
-             model->data(i2, FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>());
+             model->data(i2, FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>());
     QVERIFY(model->rowCount(i2) == 0);
     QVERIFY(model->data(i2, FreeBusyItemModel::FreeBusyRole).isValid() == false);
 
@@ -147,45 +147,45 @@ void FreeBusyItemModelTest::testModelValidity2()
     QCOMPARE(a3.fullName(),
              model->data(i3, Qt::DisplayRole).toString());
     QCOMPARE(a3,
-             model->data(i3, FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>());
+             model->data(i3, FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>());
     QVERIFY(model->rowCount(i3) == 0);
     QVERIFY(model->data(i3, FreeBusyItemModel::FreeBusyRole).isValid() == false);
 
     model->slotInsertFreeBusy(fb2, QStringLiteral("joe@example.com"));
     QCOMPARE(item2->freeBusy(),
-             model->data(i2, FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>());
+             model->data(i2, FreeBusyItemModel::FreeBusyRole).value<KCalendarCore::FreeBusy::Ptr>());
     QVERIFY(model->rowCount(i2) == fb2->fullBusyPeriods().size());
 
     QModelIndex i2_0 = model->index(0, 0, i2);
     QCOMPARE(fb2->fullBusyPeriods().first(),
              model->data(
-                 i2_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i2_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     QModelIndex i2_1 = model->index(1, 0, i2);
     QCOMPARE(fb2->fullBusyPeriods().at(1),
              model->data(
-                 i2_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i2_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     QModelIndex i2_2 = model->index(2, 0, i2);
     QCOMPARE(fb2->fullBusyPeriods().last(),
              model->data(
-                 i2_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i2_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
 
     model->slotInsertFreeBusy(fb3, QStringLiteral("max@example.com"));
     QCOMPARE(item3->freeBusy(),
-             model->data(i3, FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>());
+             model->data(i3, FreeBusyItemModel::FreeBusyRole).value<KCalendarCore::FreeBusy::Ptr>());
     QVERIFY(model->rowCount(i3) == fb3->fullBusyPeriods().size());
 
     QModelIndex i3_0 = model->index(0, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().first(),
              model->data(
-                 i3_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     QModelIndex i3_1 = model->index(1, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().at(1),
              model->data(
-                 i3_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     QModelIndex i3_2 = model->index(2, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().last(),
              model->data(
-                 i3_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
 
     model->removeAttendee(a2);
 
@@ -198,15 +198,15 @@ void FreeBusyItemModelTest::testModelValidity2()
     i3_0 = model->index(0, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().first(),
              model->data(
-                 i3_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_0, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     i3_1 = model->index(1, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().at(1),
              model->data(
-                 i3_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_1, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
     i3_2 = model->index(2, 0, i3);
     QCOMPARE(fb3->fullBusyPeriods().last(),
              model->data(
-                 i3_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalCore::FreeBusyPeriod>());
+                 i3_2, FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>());
 }
 
 void FreeBusyItemModelTest::testInsertFreeBusy()
@@ -216,18 +216,18 @@ void FreeBusyItemModelTest::testInsertFreeBusy()
 
     const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
-    KCalCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
-    KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
-    fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb1->addPeriod(dt2, KCalCore::Duration(60 * 60));
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
+    KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
+    fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb1->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
 
     const QDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), Qt::UTC);
     const QDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), Qt::UTC);
-    KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
-    fb2->addPeriod(dt1, KCalCore::Duration(60 * 60));
-    fb2->addPeriod(dt2, KCalCore::Duration(60 * 60));
-    fb2->addPeriod(dt3, KCalCore::Duration(60 * 60));
-    fb2->addPeriod(dt4, KCalCore::Duration(60 * 60 * 2));
+    KCalendarCore::FreeBusy::Ptr fb2(new KCalendarCore::FreeBusy());
+    fb2->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
+    fb2->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
+    fb2->addPeriod(dt3, KCalendarCore::Duration(60 * 60));
+    fb2->addPeriod(dt4, KCalendarCore::Duration(60 * 60 * 2));
 
     FreeBusyItem::Ptr item1(new FreeBusyItem(a1, nullptr));
     item1->setFreeBusy(fb1);
